[SCM] ci-tooling packaging branch, master, updated. 3c1e30f6bd89c209094bad33dd03013aa461f348

Harald Sitter apachelogger-guest at moszumanska.debian.org
Fri Aug 7 07:20:44 UTC 2015


Gitweb-URL: http://git.debian.org/?p=pkg-kde/ci-tooling.git;a=commitdiff;h=3c1e30f

The following commit has been merged in the master branch:
commit 3c1e30f6bd89c209094bad33dd03013aa461f348
Author: Harald Sitter <sitter at kde.org>
Date:   Fri Aug 7 09:20:37 2015 +0200

    change initial source lookup timeout to 30 minutes
    
    launchpad nowadays often doesn't manage to come up with something within
    20 minutes. I suspect it is a bit slower for some reason, if the sources
    do not turn up after 30 minutes I am content to think there is bug
    somewhere though
---
 kci/source_publisher.rb | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/kci/source_publisher.rb b/kci/source_publisher.rb
index b6e3641..36c17f1 100755
--- a/kci/source_publisher.rb
+++ b/kci/source_publisher.rb
@@ -20,15 +20,15 @@ class SourcePublisher
 
   def wait
     puts 'Waiting for source to get accepted....'
-    # If it takes 20 minutes for the source to arrive it probably got rejected.
-    fail_count = 20 # This is ~= minutes
+    # If it takes 30 minutes for the source to arrive it probably got rejected.
+    fail_count = 30 # This is ~= minutes
 
     until source
       puts 'no source yet'
       sleep(60)
       fail_count -= 1
       if fail_count <= 0
-        fail 'Upload was likely rejected, we have been waiting for well over 20 minutes!'
+        fail 'Upload was likely rejected, we have been waiting for well over 30 minutes!'
       end
     end
 

-- 
ci-tooling packaging



More information about the pkg-kde-commits mailing list